--
-- add specialization to all mods.
--
--
-- @author:    	Xentro (www.fs-uk.com)(Marcus@Xentro.se)
-- @version:    v1.52
-- @date:       2013-10-29
--

addSpecialization = {};
addSpecialization.isLoaded = true;
addSpecialization.g_currentModDirectory = g_currentModDirectory;

if SpecializationUtil.specializations["manualIgnition"] == nil then
	SpecializationUtil.registerSpecialization("manualIgnition", "manualIgnition", g_currentModDirectory .. "manualIgnition.lua")
	addSpecialization.isLoaded = false;
end;

addModEventListener(addSpecialization);

function addSpecialization:loadMap(name)	
    if not addSpecialization.isLoaded then
		addSpecialization:add();
        addSpecialization.isLoaded = true;
    end;
	
	local x = 0.01;
	local y = -0.015;
	local width = 0.0371111;
	local height = 0.256;
	
	g_currentMission.ignitionOverlay = {};
	g_currentMission.ignitionOverlay[1] = Overlay:new("ignitionOverlay1", Utils.getFilename("bg.dds", addSpecialization.g_currentModDirectory .. "Huds/"), x, y, width, height);
	g_currentMission.ignitionOverlay[2] = Overlay:new("ignitionOverlay2", Utils.getFilename("step1.dds", addSpecialization.g_currentModDirectory .. "Huds/"), x, y, width, height);
	g_currentMission.ignitionOverlay[3] = Overlay:new("ignitionOverlay3", Utils.getFilename("step2.dds", addSpecialization.g_currentModDirectory .. "Huds/"), x, y, width, height);
	g_currentMission.ignitionOverlay[4] = Overlay:new("ignitionOverlay4", Utils.getFilename("step3.dds", addSpecialization.g_currentModDirectory .. "Huds/"), x, y, width, height);
end;

function addSpecialization:deleteMap()	
	for _, hud in ipairs(g_currentMission.ignitionOverlay) do
		hud:delete();
	end;
end;

function addSpecialization:mouseEvent(posX, posY, isDown, isUp, button)
end;

function addSpecialization:keyEvent(unicode, sym, modifier, isDown)
end;

function addSpecialization:update(dt)
end;

function addSpecialization:draw()
end;

function addSpecialization:add()
	local searchWords = {"ignition"};
	local searchSpecializations = {{"manualIgnition", false}, {"steerable", true}}; -- only globally accessible scripts. (steerable, fillable etc.)
	
	for k, vehicle in pairs(VehicleTypeUtil.vehicleTypes) do
		local locationAllowed;
		
		for _, vs in ipairs(vehicle.specializations) do
			for _, s in ipairs(searchSpecializations) do
				if vs == SpecializationUtil.getSpecialization(s[1]) then
					if s[2] then
						locationAllowed = "allowed";
					else
						locationAllowed = s[1];
						break;
					end;
				end;
			end;
			
			if locationAllowed ~= nil and locationAllowed ~= "allowed" then
				break;
			end;
		end;
		
		if locationAllowed ~= nil then
			if locationAllowed == "allowed" then
				local addSpec;
				local modName = Utils.splitString(".", k);
				local spec = {};
				
				for name in pairs(SpecializationUtil.specializations) do
					if string.find(name, modName[1]) ~= nil then
						local parts = Utils.splitString(".", name);
						
						if table.getn(parts) > 1 then
							table.insert(spec, parts);
						end;
					end;
				end;
				
				for _, s in ipairs(spec) do
					for _, search in ipairs(searchWords) do
						if string.find(string.lower(s[2]), string.lower(search)) ~= nil then
							addSpec = s[2];
							break;
						end;
					end;
					
					if addSpec ~= nil then
						break;
					end;
				end;
				
				if addSpec == nil then
					table.insert(vehicle.specializations, SpecializationUtil.getSpecialization("manualIgnition"));
					-- print("Manual Ignition: Inserted on " .. k);
				else
					print("Manual Ignition: Failed inserting on " .. k .. " as it has the specialization (" .. addSpec .. ")");
				end;
			else
				print("Manual Ignition: Failed inserting on " .. k .. " as it has the specialization (" .. locationAllowed .. ")");
			end;
		end;
	end;
	
	-- make l10n global 
	local i = 1;
	while true do
		local txt = string.format("MANUAL_IGNITION_%d", i);
		if not g_i18n:hasText(txt) then
			break;
		end;
		g_i18n.globalI18N.texts[txt] = g_i18n:getText(txt);
		
		i = i + 1;
	end;
end;